PCB Environment: EnvPCB Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
EnvPCB Class Reference
Inheritance diagram for EnvPCB:

## Public Member Functions
PyObject * | reset () override
PyObject * | step (PyObject *action) override
void | render (PyObject *mode) override
void | seed (PyObject *) override
void | close () override
PyObject * | set_task (PyObject *) override
PyObject * | run_agent (PyObject *) override
PyObject * | set_agent (PyObject *) override
PyObject * | get_state (PyObject *spec) override
PyObject * | __str__ () const override
Public Member Functions inherited from Env
virtual Env * | __enter__ ()
virtual bool | __exit__ ()

## Member Function Documentation

## ◆ __str__()

PyObject * EnvPCB::__str__ | ( |  | ) | const
| overridevirtual

Implements Env.

## ◆ close()

void EnvPCB::close | ( |  | ) |
| overridevirtual

Reimplemented from Env.

## ◆ get_state()

PyObject * EnvPCB::get_state | ( | PyObject * | spec | ) |
| overridevirtual

Implements Env.

## ◆ render()

void EnvPCB::render | ( | PyObject * | mode | ) |
| overridevirtual

Implements Env.

## ◆ reset()

PyObject * EnvPCB::reset | ( |  | ) |
| overridevirtual

Implements Env.

## ◆ run_agent()

PyObject * EnvPCB::run_agent | ( | PyObject * |  | ) |
| overridevirtual

Implements Env.

## ◆ seed()

void EnvPCB::seed | ( | PyObject * |  | ) |
| overridevirtual

Implements Env.

## ◆ set_agent()

PyObject * EnvPCB::set_agent | ( | PyObject * |  | ) |
| overridevirtual

Implements Env.

## ◆ set_task()

PyObject * EnvPCB::set_task | ( | PyObject * |  | ) |
| overridevirtual

Implements Env.

## ◆ step()

PyObject * EnvPCB::step | ( | PyObject * | action | ) |
| overridevirtual

Implements Env.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/EnvPCB.hpp